@@ -19,8 +19,12 @@
 
 from __future__ import absolute_import, print_function
 
-import pkg_resources
-__version__ = pkg_resources.resource_string("lazr.restful", "version.txt").strip()
+try:
+    import importlib.metadata as importlib_metadata
+except ImportError:
+    import importlib_metadata
+
+__version__ = importlib_metadata.version("lazr.restful")
 
 # Re-export in such a way that __version__ can still be imported if
 # dependencies are not yet available.
