@@ -40,6 +40,7 @@ __all__ = [
     'operation_returns_entry',
     'operation_returns_collection_of',
     'rename_parameters_as',
+    'scoped',
     'webservice_error',
     ]
 
@@ -1059,6 +1060,28 @@ class cache_for(_method_annotator):
         annotations['cache_for'] = self.duration
 
 
+class scoped(_method_annotator):
+    """Decorator assigning scopes to a method.
+
+    This may be used to grant authentication tokens that are only valid for
+    certain webservice operations.
+
+    The decorator takes a collection of scope names as positional arguments.
+    """
+
+    def __init__(self, *scopes):
+        for scope in scopes:
+            if not isinstance(scope, six.string_types):
+                raise TypeError(
+                    'Scope should be a string type, not %s' %
+                    scope.__class__.__name__)
+        self.scopes = scopes
+
+    def annotate_method(self, method, annotations):
+        """See `_method_annotator`."""
+        annotations['scopes'] = list(self.scopes)
+
+
 class export_read_operation(_export_operation):
     """Decorator marking a method for export as a read operation."""
     type = 'read_operation'
@@ -1315,7 +1338,7 @@ def generate_entry_adapters(
                     orig_name, 'context', accessor,
                     accessor_annotations, orig_iface)
             else:
-                prop = Passthrough(orig_name, 'context', orig_iface)
+                prop = _ScopeChecker(orig_name, 'context', orig_iface)
 
             adapter_dict[tags['as']] = prop
 
@@ -1359,11 +1382,40 @@ def params_with_dereferenced_user(params):
     return params
 
 
+def _check_request(context, required_scopes):
+    """Check whether the current request may call a particular method.
+
+    See `IWebServiceConfiguration.checkRequest`.
+    """
+    check_request = getattr(
+        getUtility(IWebServiceConfiguration), 'checkRequest', None)
+    if check_request is not None:
+        check_request(context, required_scopes)
+
+
+class _ScopeChecker(Passthrough):
+    """Check scopes before allowing access to properties."""
+
+    def __get__(self, inst, cls=None):
+        context = getattr(inst, self.contextvar)
+        if self.adaptation is not None:
+            context = self.adaptation(context)
+        _check_request(context, None)
+        return super(_ScopeChecker, self).__get__(inst, cls=cls)
+
+    def __set__(self, inst, value):
+        context = getattr(inst, self.contextvar)
+        if self.adaptation is not None:
+            context = self.adaptation(context)
+        _check_request(context, None)
+        return super(_ScopeChecker, self).__set__(inst, value)
+
+
 class _AccessorWrapper:
     """A wrapper class for properties with accessors.
 
     We define this separately from PropertyWithAccessor and
-    PropertyWithAccessorAndMutator to avoid multple inheritance issues.
+    PropertyWithAccessorAndMutator to avoid multiple inheritance issues.
     """
 
     def __get__(self, obj, *args):
@@ -1373,6 +1425,7 @@ class _AccessorWrapper:
         context = getattr(obj, self.contextvar)
         if self.adaptation is not None:
             context = self.adaptation(context)
+        _check_request(context, None)
         # Error checking code in accessor_for() guarantees that there
         # is one and only one non-fixed parameter for the accessor
         # method.
@@ -1383,7 +1436,7 @@ class _MutatorWrapper:
     """A wrapper class for properties with mutators.
 
     We define this separately from PropertyWithMutator and
-    PropertyWithAccessorAndMutator to avoid multple inheritance issues.
+    PropertyWithAccessorAndMutator to avoid multiple inheritance issues.
     """
 
     def __set__(self, obj, new_value):
@@ -1393,13 +1446,14 @@ class _MutatorWrapper:
         context = getattr(obj, self.contextvar)
         if self.adaptation is not None:
             context = self.adaptation(context)
+        _check_request(context, None)
         # Error checking code in mutator_for() guarantees that there
         # is one and only one non-fixed parameter for the mutator
         # method.
         getattr(context, self.mutator)(new_value, **params)
 
 
-class PropertyWithAccessor(_AccessorWrapper, Passthrough):
+class PropertyWithAccessor(_AccessorWrapper, _ScopeChecker):
     """A property with a accessor method."""
 
     def __init__(self, name, context, accessor, accessor_annotations,
@@ -1409,7 +1463,7 @@ class PropertyWithAccessor(_AccessorWrapper, Passthrough):
         self.accessor_annotations = accessor_annotations
 
 
-class PropertyWithMutator(_MutatorWrapper, Passthrough):
+class PropertyWithMutator(_MutatorWrapper, _ScopeChecker):
     """A property with a mutator method."""
 
     def __init__(self, name, context, mutator, mutator_annotations,
@@ -1542,6 +1596,7 @@ class BaseResourceOperationAdapter(ResourceOperation):
                 'Cache-control', 'max-age=%i'
                 % self._export_info['cache_for'])
 
+        _check_request(self.context, self._export_info.get('scopes', []))
         result = self._getMethod()(**params)
         return self.encodeResult(result)
 
@@ -1613,6 +1668,7 @@ def generate_operation_adapter(method, version=None):
         raise AssertionError('Unknown method export type: %s' % operation_type)
 
     return_type = match['return_type']
+    scopes = match.get('scopes') or []
 
     name = _versioned_class_name(
         '%s_%s_%s' % (prefix, method.interface.__name__, match['as']),
@@ -1620,6 +1676,7 @@ def generate_operation_adapter(method, version=None):
     class_dict = {
         'params': tuple(match['params'].values()),
         'return_type': return_type,
+        'scopes': tuple(scopes),
         '_orig_iface': method.interface,
         '_export_info': match,
         '_method_name': method.__name__,
