@@ -2,6 +2,8 @@
 
 """The file manager for the LAZR example web service."""
 
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 __all__ = ['FileManager',
            'ManagedFileResource']
@@ -15,7 +17,7 @@ except ImportError:
      import sha
      sha_constructor = sha.new
 
-from zope.interface import implements
+from zope.interface import implementer
 
 import grokcore.component
 
@@ -24,8 +26,8 @@ from lazr.restful.example.base.interfaces import IFileManager
 from lazr.restful.utils import get_current_web_service_request
 
 
+@implementer(IFileManager)
 class FileManager:
-    implements(IFileManager)
 
     def __init__(self):
         """Initialize with an empty list of files."""
