@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 
 __all__ = ['IKeyValuePair',
@@ -5,16 +7,25 @@ __all__ = ['IKeyValuePair',
            'KeyValuePair',
            'PairSet']
 
-from zope.interface import implements
+from zope.interface import implementer
 from zope.schema import Bool, Text
 from zope.location.interfaces import ILocation
 
 from lazr.restful.declarations import (
-    collection_default_content, export_as_webservice_collection,
-    export_as_webservice_entry, export_destructor_operation,
-    export_operation_as, export_read_operation, export_write_operation,
-    exported, mutator_for, operation_for_version, operation_parameters,
-    operation_removed_in_version, operation_returns_collection_of)
+    collection_default_content,
+    export_destructor_operation,
+    export_operation_as,
+    export_read_operation,
+    export_write_operation,
+    exported,
+    exported_as_webservice_collection,
+    exported_as_webservice_entry,
+    mutator_for,
+    operation_for_version,
+    operation_parameters,
+    operation_removed_in_version,
+    operation_returns_collection_of,
+    )
 
 # Our implementations of these classes can be based on the
 # implementations from the WSGI example.
@@ -24,8 +35,8 @@ from lazr.restful.example.wsgi.resources import (
 
 # Our interfaces _will_ diverge from the WSGI example interfaces, so
 # define them separately.
+@exported_as_webservice_entry()
 class IKeyValuePair(ILocation):
-    export_as_webservice_entry()
     key = exported(Text(title=u"The key"))
     value = exported(Text(title=u"The value"))
     a_comment = exported(Text(title=u"A comment on this key-value pair.",
@@ -59,9 +70,8 @@ class IKeyValuePair(ILocation):
         """A destructor that simply sets .deleted to True."""
 
 
+@exported_as_webservice_collection(IKeyValuePair)
 class IPairSet(ILocation):
-    export_as_webservice_collection(IKeyValuePair)
-
     # In versions 2.0 and 3.0, the collection of key-value pairs
     # includes all pairs.
     @collection_default_content("2.0")
@@ -92,8 +102,8 @@ class IPairSet(ILocation):
         """Find key-value pairs that have the given value."""
 
 
+@implementer(IPairSet)
 class PairSet(BasicPairSet):
-    implements(IPairSet)
 
     def find_for_value(self, value):
         return [pair for pair in self.pairs if value == pair.value]
@@ -102,8 +112,8 @@ class PairSet(BasicPairSet):
         return [pair for pair in self.pairs if pair.value is not None]
 
 
+@implementer(IKeyValuePair)
 class KeyValuePair(BasicKeyValuePair):
-    implements(IKeyValuePair)
 
     def __init__(self, pairset, key, value):
         super(KeyValuePair, self).__init__(pairset, key, value)
