@@ -652,6 +652,26 @@ class IWebServiceConfiguration(Interface):
         value will be fed back into your code.
         """
 
+    def checkRequest(context, required_scopes):
+        """Check whether the current request may call a particular method.
+
+        Authenticated users may be limited to certain scopes, in which case
+        they will only be able to use methods with corresponding `@scoped`
+        decorators.  This method is called to check whether a call to a
+        method on `context` tagged with `required_scopes` should be allowed.
+        The return value is ignored; it only matters whether this raises a
+        `zope.security.interfaces.Unauthorized` exception.
+
+        For compatibility, if this method is unimplemented, it is treated as
+        if it did not raise an exception.
+
+        :param context: The context object.
+        :param required_scopes: A list of scope names for this method, or
+            None if the method is unscoped.
+        :raises zope.security.interfaces.Unauthorized: if the call should
+            not be allowed.
+        """
+
 
 class IUnmarshallingDoesntNeedValue(Interface):
     """A marker interface for unmarshallers that work without values.
