@@ -20,6 +20,7 @@ __all__ = [
 
 import traceback
 
+import six
 from six.moves.urllib.parse import (
     quote,
     unquote,
@@ -370,8 +371,10 @@ class MultiplePathPartAbsoluteURL:
         parts = getattr(self.context, '__path_parts__', None)
         if parts is None:
             raise TypeError(_insufficientContext)
-        if not hasattr(parts, '__iter__'):
-            raise TypeError("Expected an iterable for __path_parts__.")
+        if (isinstance(parts, six.string_types) or
+                not hasattr(parts, '__iter__')):
+            raise TypeError(
+                "Expected an iterable of strings for __path_parts__.")
 
         escaped_parts = [quote(part.encode('utf-8'), _safe) for part in parts]
         return start_url + "/" + "/".join(escaped_parts)
