@@ -804,7 +804,13 @@ class WadlOperationAPI(RESTUtilityBase):
     @property
     def doc(self):
         """Human-readable documentation for this operation."""
-        return generate_wadl_doc(self.operation.__doc__)
+        docstring = self.operation.__doc__
+        # Hack scope information into the docstring for now.
+        scopes = getattr(self.operation, 'scopes', None)
+        if scopes:
+            docstring += '\n\nScopes: %s\n' % (
+                ', '.join("``%s``" % scope for scope in scopes))
+        return generate_wadl_doc(docstring)
 
     @property
     def has_return_type(self):
