@@ -47,6 +47,7 @@ from zope.publisher.paste import Application
 from zope.proxy import ProxyBase
 from zope.schema import TextLine
 from zope.security.checker import ProxyFactory
+from zope.security.interfaces import Unauthorized
 from zope.testing.cleanup import CleanUp
 from zope.traversing.browser.interfaces import IAbsoluteURL
 
@@ -565,6 +566,7 @@ class WebServiceTestConfiguration(BaseWebServiceConfiguration):
     active_versions = ['1.0', '2.0']
     hostname = "webservice_test"
     last_version_with_mutator_named_operations = None
+    _scopes = None
 
     def createRequest(self, body_instream, environ):
         request = Request(body_instream, environ)
@@ -573,6 +575,19 @@ class WebServiceTestConfiguration(BaseWebServiceConfiguration):
         tag_request_with_version_name(request, '2.0')
         return request
 
+    def checkRequest(self, obj, required_scopes):
+        if self._scopes is not None:
+            if not required_scopes:
+                raise Unauthorized(
+                    'Current authentication only allows calling '
+                    'scoped methods.')
+            elif not any(scope in required_scopes for scope in self._scopes):
+                raise Unauthorized(
+                    'Current authentication does not allow calling '
+                    'this method (one of these scopes is required: '
+                    '%s).'
+                    % ', '.join("'%s'" % scope for scope in required_scopes))
+
 
 class IWebServiceTestRequest10(IWebServiceClientRequest):
     """A marker interface for requests to the '1.0' web service."""
