@@ -28,6 +28,7 @@ from zope.security.checker import (
     MultiChecker,
     ProxyFactory,
     )
+from zope.security.interfaces import Unauthorized
 from zope.security.management import (
     endInteraction,
     newInteraction,
@@ -339,6 +340,37 @@ class ContributingInterfacesTestCase(TestCaseWithWebServiceFixtures):
         self.assertEqual(
             'product', EntryAdapterUtility(adapter.__class__).singular_type)
 
+    def test_accessor_for_with_scopes(self):
+        # Users with scopes cannot use accessors.
+        self.product._branches = [
+            Branch('A branch'), Branch('Another branch')]
+        register_test_module('testmod', IBranch, IProduct, IHasBranches)
+        config = getUtility(IWebServiceConfiguration)
+        config._scopes = ['scope']
+        self.addCleanup(setattr, config, '_scopes', None)
+        adapter = getMultiAdapter(
+            (self.product, self.one_zero_request), IEntry)
+        exception = self.assertRaises(
+            Unauthorized, getattr, adapter, 'branches')
+        self.assertEqual(
+            'Current authentication only allows calling scoped methods.',
+            str(exception))
+
+    def test_mutator_for_with_scopes(self):
+        # Users with scopes cannot use mutators.
+        self.product._dev_branch = Branch('A product branch')
+        register_test_module('testmod', IBranch, IProduct, IHasBranches)
+        config = getUtility(IWebServiceConfiguration)
+        config._scopes = ['scope']
+        self.addCleanup(setattr, config, '_scopes', None)
+        adapter = getMultiAdapter(
+            (self.product, self.two_zero_request), IEntry)
+        exception = self.assertRaises(
+            Unauthorized, setattr, adapter, 'development_branch_20', None)
+        self.assertEqual(
+            'Current authentication only allows calling scoped methods.',
+            str(exception))
+
 
 class TestExportAsWebserviceEntry(testtools.TestCase):
     """Tests for export_as_webservice_entry."""
